import setuptools

setuptools.setup(
     name='tradingcornerstone',  
     version='0.1',
     scripts=['tradingcornerstone'] ,
     author="f1",
     author_email="ll@gmail.com",
     description="Place holder!",
     long_description="Place Holder!",
     url="https://placeholder",
     packages=setuptools.find_packages(),
     classifiers=[
         "Development Status :: 1 - Planning",
     ],
 )